get_commitment_secret

Function get_commitment_secret 

pub fn get_commitment_secret(
    commitment_seed: &[u8; 32],
    commitment_number: u64,
) -> [u8; 32]
Derive the commitment secret for a given commitment number from a seed.

The commitment number should be in the range [0, 2^48).