pub struct ChannelTlcInfo {
pub timestamp: u64,
pub enabled: bool,
pub tlc_fee_proportional_millionths: u128,
pub tlc_expiry_delta: u64,
pub tlc_minimum_value: u128,
}Expand description
TLC-related information for a channel. We can update this information through the channel update message.
Fields
timestamp: u64The timestamp when the following information is updated.
enabled: boolWhether this channel is enabled for TLC forwarding or not.
tlc_fee_proportional_millionths: u128The fee rate for TLC transfers. We only have these values set when
this is a public channel. Both sides may set this value differently.
This is a fee that is paid by the sender of the TLC.
The detailed calculation for the fee of forwarding TLCs is
fee = round_above(tlc_fee_proportional_millionths * tlc_value / 1,000,000).
tlc_expiry_delta: u64The expiry delta timestamp, in milliseconds, for the TLC.
tlc_minimum_value: u128The minimal TLC value we can receive in relay TLC.
Implementations