ChannelUpdateInfo

Struct ChannelUpdateInfo 

pub struct ChannelUpdateInfo {
    pub timestamp: u64,
    pub enabled: bool,
    pub outbound_liquidity: Option<u128>,
    pub tlc_expiry_delta: u64,
    pub tlc_minimum_value: u128,
    pub fee_rate: u64,
}
The channel update info with a single direction of channel.

This is a pure data struct used by both the internal graph representation and the RPC JSON response types.

Fields

timestamp: u64

The timestamp is the time when the channel update was received by the node.

enabled: bool

Whether the channel can be currently used for payments (in this one direction).

outbound_liquidity: Option<u128>

The exact amount of balance that we can send to the other party via the channel.

tlc_expiry_delta: u64

The difference in htlc expiry values that you must have when routing through this channel (in milliseconds).

tlc_minimum_value: u128

The minimum value, which must be relayed to the next hop via the channel

fee_rate: u64

The forwarding fee rate for the channel.