pub struct HopRequire {
pub pubkey: Pubkey,
pub channel_outpoint: Option<OutPoint>,
}Expand description
A hop requirement to meet when building a router. Does not include the source node; the last hop is the target node.
Fields
pubkey: PubkeyThe public key of the node
channel_outpoint: Option<OutPoint>The outpoint for the channel, which means use channel with channel_outpoint to reach this node