pub struct PaymentOnionPacket { /* private fields */ }Expand description
An encrypted onion packet for payment routing.
Implementations
Sourceimpl PaymentOnionPacket
impl PaymentOnionPacket
Sourcepub fn into_bytes(self) -> Vec<u8> ⓘ
pub fn into_bytes(self) -> Vec<u8> ⓘ
Consume self and return the raw data as bytes (alias for into_data()).
Sourcepub fn into_sphinx_onion_packet(self) -> Result<OnionPacket, OnionPacketError>
pub fn into_sphinx_onion_packet(self) -> Result<OnionPacket, OnionPacketError>
Convert into the raw Sphinx onion packet.
Sourcepub fn peel<C: Verification>(
self,
peeler: &Privkey,
assoc_data: Option<&[u8]>,
secp_ctx: &Secp256k1<C>,
) -> Result<PeeledPaymentOnionPacket, OnionPacketError>
pub fn peel<C: Verification>( self, peeler: &Privkey, assoc_data: Option<&[u8]>, secp_ctx: &Secp256k1<C>, ) -> Result<PeeledPaymentOnionPacket, OnionPacketError>
Peels the next layer of the onion packet using the privkey of the current node.
Returns errors when:
- This is the packet for the last hop.
- Fail to peel the packet using the given private key.