pub struct TlcErrPacket {
pub onion_packet: Vec<u8>,
}Expand description
An encrypted error packet for TLC failures. The sender should decode it and then decide what to do with the error. Note: this is supposed to be only accessible by the sender, and it’s not reliable since it is not placed on-chain due to the possibility of hop failure.
Fields
onion_packet: Vec<u8>Implementations
Sourceimpl TlcErrPacket
impl TlcErrPacket
Sourcepub fn from_payload(payload: Vec<u8>, shared_secret: &[u8; 32]) -> Self
pub fn from_payload(payload: Vec<u8>, shared_secret: &[u8; 32]) -> Self
Create a new TlcErrPacket from raw payload bytes. Erring node creates the error packet using the shared secret used in forwarding onion packet. Use all zeros (NO_SHARED_SECRET) for the origin node.
Sourcepub fn is_plaintext(&self) -> bool
pub fn is_plaintext(&self) -> bool
Check if this packet is plaintext (not encrypted).