pub struct RouterHop {
pub target: Pubkey,
pub channel_outpoint: OutPoint,
pub amount_received: u128,
pub incoming_tlc_expiry: u64,
}Expand description
A router hop information for a payment, a paymenter router is an array of RouterHop,
a router hop generally implies hop target will receive amount_received with channel_outpoint of channel.
Improper hop hint may make payment fail, for example the specified channel do not have enough capacity.
Fields
target: PubkeyThe node that is sending the TLC to the next node.
channel_outpoint: OutPointThe channel of this hop used to receive TLC
amount_received: u128The amount that the source node will transfer to the target node. We have already added up all the fees along the path, so this amount can be used directly for the TLC.
incoming_tlc_expiry: u64The expiry for the TLC that the source node sends to the target node. We have already added up all the expiry deltas along the path, the only thing missing is current time. So the expiry is the current time plus the expiry delta.