SendPaymentData

Struct SendPaymentData 

pub struct SendPaymentData {
Show 20 fields pub target_pubkey: Pubkey, pub amount: u128, pub payment_hash: Hash256, pub invoice: Option<String>, pub final_tlc_expiry_delta: u64, pub tlc_expiry_limit: u64, pub timeout: Option<u64>, pub max_fee_amount: Option<u128>, pub max_parts: Option<u64>, pub keysend: bool, pub udt_type_script: Option<Script>, pub preimage: Option<Hash256>, pub custom_records: Option<PaymentCustomRecords>, pub allow_self_payment: bool, pub hop_hints: Vec<HopHint>, pub router: Vec<RouterHop>, pub allow_mpp: bool, pub dry_run: bool, pub trampoline_hops: Option<Vec<Pubkey>>, pub trampoline_context: Option<TrampolineContext>,
}
Data for sending a payment.

Fields

target_pubkey: Pubkeyamount: u128payment_hash: Hash256invoice: Option<String>final_tlc_expiry_delta: u64tlc_expiry_limit: u64timeout: Option<u64>max_fee_amount: Option<u128>max_parts: Option<u64>

The number of parts for the payment, only used for multi-part payment

keysend: booludt_type_script: Option<Script>preimage: Option<Hash256>custom_records: Option<PaymentCustomRecords>allow_self_payment: boolhop_hints: Vec<HopHint>router: Vec<RouterHop>allow_mpp: bool

This flag indicates the invoice whether to allow multi-path payment.

dry_run: booltrampoline_hops: Option<Vec<Pubkey>>

Optional explicit trampoline hops.

When set to a non-empty list [t1, t2, ...], routing will only find a path from the payer to t1, and the inner trampoline onion will encode t1 -> t2 -> ... -> final.

trampoline_context: Option<TrampolineContext>

Implementations

Source

impl SendPaymentData

pub fn max_parts(&self) -> usize

Maximum number of parallel parts for this payment.

pub fn allow_mpp(&self) -> bool

Whether this payment allows multi-path payment (MPP).

pub fn use_trampoline_routing(&self) -> bool

Whether this payment uses trampoline routing.