pub struct SessionRoute {
pub nodes: Vec<SessionRouteNode>,
}Expand description
The router is a list of nodes that the payment will go through.
We store in the payment session and then will use it to track the payment history.
The router is a list of nodes that the payment will go through.
For example:
A(amount, channel) -> B -> C -> D
means A will send amount with channel to B.
Fields
nodes: Vec<SessionRouteNode>the nodes in the route
Implementations
Sourceimpl SessionRoute
impl SessionRoute