pub struct TrampolineContext {
pub remaining_trampoline_onion: Vec<u8>,
pub previous_tlcs: Vec<PrevTlcInfo>,
pub hash_algorithm: HashAlgorithm,
}Expand description
Context for trampoline routing payments.
Fields
remaining_trampoline_onion: Vec<u8>Optional final trampoline onion packet.
When provided, this onion packet will be attached to the payload of the next hop (which in this context is the next trampoline node).
previous_tlcs: Vec<PrevTlcInfo>Previous TLCs information for the payment session. This is used to associate the outgoing payment with the incoming payment.
hash_algorithm: HashAlgorithmHash algorithm used for the payment.