Module primitives

Module primitives 

Layer 1: Basic primitive types — Hash256, Pubkey, Privkey, NodeId.

Structs

ChannelUpdateChannelFlags
ChannelUpdateMessageFlags
Hash256
A 256-bit hash digest, used as identifier of channel, payment, transaction hash etc.
NodeId
Used as identifier of node.
Privkey
A wrapper for secp256k1 secret key
Pubkey
A compressed secp256k1 public key (33 bytes), used as the primary identity of a node. In the RPC interface this value is exposed as fields such as pubkey. It is serialized as a 66-character hex string (e.g. "02aaaa...") in JSON.