Module feature_bits

Module feature_bits 

Feature bits and methods for the Fiber protocol. Pair bits: a feature can be introduced as optional (odd bits) and later upgraded to be compulsory (even bits).

  • Even bits are used to signify that the feature is required.
  • Odd bits are used to signify that the feature is optional.

Constants

BASIC_MPP_OPTIONAL
Odd bit, the bit used to signify that the feature is optional.
BASIC_MPP_REQUIRED
Even bit, the bit used to signify that the feature is required.
GOSSIP_QUERIES_OPTIONAL
Odd bit, the bit used to signify that the feature is optional.
GOSSIP_QUERIES_REQUIRED
Even bit, the bit used to signify that the feature is required.
MAX_FEATURE_BIT
TRAMPOLINE_ROUTING_OPTIONAL
Odd bit, the bit used to signify that the feature is optional.
TRAMPOLINE_ROUTING_REQUIRED
Even bit, the bit used to signify that the feature is required.

Functions

feature_bit_name