pub struct ChannelAnnouncement {
pub node1_signature: Option<EcdsaSignature>,
pub node2_signature: Option<EcdsaSignature>,
pub ckb_signature: Option<SchnorrSignature>,
pub features: u64,
pub chain_hash: Hash256,
pub channel_outpoint: OutPoint,
pub node1_id: Pubkey,
pub node2_id: Pubkey,
pub ckb_key: XOnlyPublicKey,
pub capacity: u128,
pub udt_type_script: Option<Script>,
}Expand description
Announcement of a new channel in the network.
This message is broadcast to all nodes to inform them about a new channel. It contains the channel’s capacity, the nodes involved, and signatures.
Fields
node1_signature: Option<EcdsaSignature>Signature from node 1
node2_signature: Option<EcdsaSignature>Signature from node 2
ckb_signature: Option<SchnorrSignature>Signature signed by the funding transaction output public key
features: u64Feature flags for the channel
chain_hash: Hash256The chain hash this channel belongs to
channel_outpoint: OutPointThe outpoint of the funding transaction
node1_id: PubkeyPublic key of node 1
node2_id: PubkeyPublic key of node 2
ckb_key: XOnlyPublicKeyThe aggregated public key of the funding transaction output
capacity: u128The total capacity of the channel
udt_type_script: Option<Script>UDT type script if this is a UDT channel
Implementations
Sourceimpl ChannelAnnouncement
impl ChannelAnnouncement
Sourcepub fn new_unsigned(
node1_pubkey: &Pubkey,
node2_pubkey: &Pubkey,
channel_outpoint: OutPoint,
chain_hash: Hash256,
ckb_pubkey: &XOnlyPublicKey,
capacity: u128,
udt_type_script: Option<Script>,
) -> Self
pub fn new_unsigned( node1_pubkey: &Pubkey, node2_pubkey: &Pubkey, channel_outpoint: OutPoint, chain_hash: Hash256, ckb_pubkey: &XOnlyPublicKey, capacity: u128, udt_type_script: Option<Script>, ) -> Self
Create an unsigned channel announcement with the given parameters.
Sourceimpl ChannelAnnouncement
impl ChannelAnnouncement
Sourcepub fn message_to_sign(&self) -> [u8; 32]
pub fn message_to_sign(&self) -> [u8; 32]
Get the message bytes to sign (hash of unsigned molecule serialization).