ChannelUpdate

Struct ChannelUpdate 

pub struct ChannelUpdate {
    pub signature: Option<EcdsaSignature>,
    pub chain_hash: Hash256,
    pub channel_outpoint: OutPoint,
    pub timestamp: u64,
    pub message_flags: ChannelUpdateMessageFlags,
    pub channel_flags: ChannelUpdateChannelFlags,
    pub tlc_expiry_delta: u64,
    pub tlc_minimum_value: u128,
    pub tlc_fee_proportional_millionths: u128,
}
Update to an existing channel’s routing parameters.

This message is broadcast to update routing information for a channel, such as fees, timelock requirements, or disabled status.

Fields

signature: Option<EcdsaSignature>

Signature of the node that wants to update the channel information

chain_hash: Hash256

The chain hash this channel belongs to

channel_outpoint: OutPoint

The outpoint of the funding transaction

timestamp: u64

Timestamp for this update

message_flags: ChannelUpdateMessageFlags

Message flags (indicates which node this update is from)

channel_flags: ChannelUpdateChannelFlags

Channel flags (indicates if channel is disabled)

tlc_expiry_delta: u64

TLC expiry delta in blocks

tlc_minimum_value: u128

Minimum TLC value

tlc_fee_proportional_millionths: u128

Fee proportional millionths

Implementations

Source

impl ChannelUpdate

pub fn is_update_of_node_1(&self) -> bool

Check if this update is from node 1.

pub fn is_update_of_node_2(&self) -> bool

Check if this update is from node 2.

pub fn is_disabled(&self) -> bool

Check if the channel is disabled.

pub fn message_to_sign(&self) -> [u8; 32]

Get the message bytes to sign (hash of unsigned molecule serialization).

pub fn cursor(&self) -> Cursor

Get the cursor for this channel update.