Network state types.
Contains the persistent network actor state that is stored in the node’s database.
Structs
- HopRequire
- A hop requirement to meet when building a router. Does not include the source node; the last hop is the target node.
- Persistent
Network Actor State - The persistent state of the network actor.