pub struct PaymentSphinxCodec;Expand description
Codec for payment onion packets (used by the outer payment onion layer).
Implementations
Sourceimpl PaymentSphinxCodec
impl PaymentSphinxCodec
Sourcepub fn pack_hop_data(version: u8, hop_data: &PaymentHopData) -> Vec<u8> ⓘ
pub fn pack_hop_data(version: u8, hop_data: &PaymentHopData) -> Vec<u8> ⓘ
Packs hop data according to the specified onion packet version.
- Version 0: Prepends u64 BE length header before molecule data.
- Version 1: Returns molecule-serialized data directly (uses molecule’s native u32 LE length).
Sourcepub fn unpack_hop_data(version: u8, buf: &[u8]) -> Option<PaymentHopData>
pub fn unpack_hop_data(version: u8, buf: &[u8]) -> Option<PaymentHopData>
Unpacks hop data according to the specified onion packet version.
- Version 0: Skips u64 BE length header, deserializes molecule data.
- Version 1: Deserializes molecule data directly (using molecule’s u32 LE length).
- Unknown versions: Returns None to fail fast and avoid silent misparsing.