pub enum PaymentStatus {
Created,
Inflight,
Success,
Failed,
}Expand description
The status of a payment, will update as the payment progresses.
The transfer path for payment status is Created -> Inflight -> Success | Failed.
MPP Behavior: A single session may involve multiple attempts (HTLCs) to fulfill the total amount.
Variants
Created
Initial status. A payment session is created, but no HTLC has been dispatched.
Inflight
The first hop AddTlc is sent successfully and waiting for the response.
MPP Logic: Status
Inflightmeans at least one attempt is still not inSuccess, payment needs more retrying or waiting for HTLC settlement.
Success
The payment is finished. All related HTLCs are successfully settled, and the aggregate amount equals the total requested amount.
Failed
The payment session has terminated. HTLCs have failed and the target amount cannot be fulfilled after exhausting all retries.
Implementations