A router hop information for a payment, a paymenter router is an array of RouterHop,
a router hop generally implies hop target will receive amount_received with channel_outpoint of channel.
Improper hop hint may make payment fail, for example the specified channel do not have enough capacity.
The amount that the source node will transfer to the target node.
We have already added up all the fees along the path, so this amount can be used directly for the TLC.
The expiry for the TLC that the source node sends to the target node.
We have already added up all the expiry deltas along the path,
the only thing missing is current time. So the expiry is the current time plus the expiry delta.