Feature bits and methods for the Fiber protocol. Pair bits: a feature can be introduced as optional (odd bits) and later upgraded to be compulsory (even bits).
- Even bits are used to signify that the feature is required.
- Odd bits are used to signify that the feature is optional.
Constants
- BASIC_
MPP_ OPTIONAL - Odd bit, the bit used to signify that the feature is optional.
- BASIC_
MPP_ REQUIRED - Even bit, the bit used to signify that the feature is required.
- GOSSIP_
QUERIES_ OPTIONAL - Odd bit, the bit used to signify that the feature is optional.
- GOSSIP_
QUERIES_ REQUIRED - Even bit, the bit used to signify that the feature is required.
- MAX_
FEATURE_ BIT - TRAMPOLINE_
ROUTING_ OPTIONAL - Odd bit, the bit used to signify that the feature is optional.
- TRAMPOLINE_
ROUTING_ REQUIRED - Even bit, the bit used to signify that the feature is required.