pub struct ChannelUpdate {
pub signature: Option<EcdsaSignature>,
pub chain_hash: Hash256,
pub channel_outpoint: OutPoint,
pub timestamp: u64,
pub message_flags: ChannelUpdateMessageFlags,
pub channel_flags: ChannelUpdateChannelFlags,
pub tlc_expiry_delta: u64,
pub tlc_minimum_value: u128,
pub tlc_fee_proportional_millionths: u128,
}Expand description
Update to an existing channel’s routing parameters.
This message is broadcast to update routing information for a channel, such as fees, timelock requirements, or disabled status.
Fields
signature: Option<EcdsaSignature>Signature of the node that wants to update the channel information
chain_hash: Hash256The chain hash this channel belongs to
channel_outpoint: OutPointThe outpoint of the funding transaction
timestamp: u64Timestamp for this update
message_flags: ChannelUpdateMessageFlagsMessage flags (indicates which node this update is from)
channel_flags: ChannelUpdateChannelFlagsChannel flags (indicates if channel is disabled)
tlc_expiry_delta: u64TLC expiry delta in blocks
tlc_minimum_value: u128Minimum TLC value
tlc_fee_proportional_millionths: u128Fee proportional millionths
Implementations
Sourceimpl ChannelUpdate
impl ChannelUpdate
Sourcepub fn is_update_of_node_1(&self) -> bool
pub fn is_update_of_node_1(&self) -> bool
Check if this update is from node 1.
Sourcepub fn is_update_of_node_2(&self) -> bool
pub fn is_update_of_node_2(&self) -> bool
Check if this update is from node 2.
Sourcepub fn is_disabled(&self) -> bool
pub fn is_disabled(&self) -> bool
Check if the channel is disabled.
Sourcepub fn message_to_sign(&self) -> [u8; 32]
pub fn message_to_sign(&self) -> [u8; 32]
Get the message bytes to sign (hash of unsigned molecule serialization).